@@ -9,7 +9,7 @@ sub _get_qrcode_image{
     ); 
     my $r = $self->http_get(Weixin::Util::gen_url($api . "/$qrcode_uuid",@query_string));
     return undef unless defined $r;
-    my ($fh, $filename) = tempfile("weixin_qrcode_XXXX",SUFFIX =>".jpg",TMPDIR => 1); 
+    my ($fh, $filename) = tempfile("weixin_qrcode_XXXX",SUFFIX =>".jpg",DIR => $self->{tmpdir}); 
     binmode $fh;
     print $fh $r;
     close $fh;
